package com.persagy.dmp.define.controller;

import cn.hutool.core.collection.CollUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.persagy.dmp.basic.utils.DigitalCommonUtils;
import com.persagy.dmp.basic.utils.QueryCriteriaHelper;
import com.persagy.dmp.common.constant.ResponseCode;
import com.persagy.dmp.common.exception.BusinessException;
import com.persagy.dmp.common.model.response.CommonResult;
import com.persagy.dmp.common.model.response.PageList;
import com.persagy.dmp.basic.model.QueryCriteria;
import com.persagy.dmp.common.utils.ResultHelper;
import com.persagy.dmp.define.entity.ObjectTypeDefine;
import com.persagy.dmp.define.service.IObjectTypeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;

/**
 * 对象类型 Controller
 * @author Charlie Yu
 * @date 2021-06-25
 */
@RestController
@RequestMapping("/define/type")
public class ObjectTypeController {

    @Autowired
    private IObjectTypeService service;

    @PostMapping("query")
    public CommonResult<PageList<ObjectTypeDefine>> query(@RequestBody QueryCriteria criteria) {
        if(criteria == null) {
            throw new BusinessException(ResponseCode.A0400.getCode(), ResponseCode.A0400.getDesc());
        }
        QueryWrapper<ObjectTypeDefine> wrapper = new QueryWrapper<>();
        // 添加所属项目条件
        DigitalCommonUtils.ensureProjectCriteria(wrapper);
        // 转换查询条件
        QueryCriteriaHelper.toWrapper(wrapper, criteria);
        Page page = service.queryByCondition(QueryCriteriaHelper.toPage(criteria), wrapper);
        return ResultHelper.multi(page.getRecords(), page.getTotal());
    }

    @PostMapping("/create")
	public CommonResult<ObjectTypeDefine> create(@Valid @RequestBody ObjectTypeDefine vo){
        List<ObjectTypeDefine> voList = CollUtil.newArrayList(vo);
        service.insert(voList);
		return ResultHelper.single(vo);
	}

    @PostMapping("/createBatch")
    public CommonResult<PageList<ObjectTypeDefine>> createBatch(@Valid @RequestBody List<ObjectTypeDefine> voList){
        voList = service.insert(voList);
        return ResultHelper.multi(voList);
    }

	@PostMapping("/update")
	public CommonResult<ObjectTypeDefine> update(@Valid @RequestBody ObjectTypeDefine vo){
        List<ObjectTypeDefine> voList = CollUtil.newArrayList(vo);
        service.update(voList);
		return ResultHelper.single(vo);
	}

    @PostMapping("/updateBatch")
    public CommonResult<PageList<ObjectTypeDefine>> updateBatch(@Valid @RequestBody List<ObjectTypeDefine> voList){
        voList = service.update(voList);
        return ResultHelper.multi(voList);
    }

	@PostMapping("/delete")
	public CommonResult delete(@RequestBody String id){
        service.delete(CollUtil.newArrayList(id));
        return ResultHelper.success();
	}

    @PostMapping("/deleteBatch")
    public CommonResult deleteBatch(@RequestBody List<String> id){
        service.delete(id);
        return ResultHelper.success();
    }
}
